package Bundle::Locale::CLDR::Americas;

use version;

our $VERSION = version->declare('v0.34.0');

=head1 NAME Bundle::Locale::CLDR::Americas

=head1 CONTENTS

Bundle::Locale::CLDR::Caribbean 0.34.0
Bundle::Locale::CLDR::Latinamerica 0.34.0
Bundle::Locale::CLDR::Northamerica 0.34.0
Bundle::Locale::CLDR::Southamerica 0.34.0
Bundle::Locale::CLDR::Centralamerica 0.34.0
Bundle::Locale::CLDR::Northernamerica 0.34.0

=cut

1;

